@@ -11,3 +11,7 @@ pub struct Pages;
 #[derive(RustEmbed)]
 #[folder = "out"]
 pub struct Compiled;
+
+#[derive(RustEmbed)]
+#[folder = "template/scripts/external"]
+pub struct ExternalScripts;
