@@ -21,6 +21,17 @@ class ApiClient {
     const { data } = await response.json()
     return data
   }
+
+  async delete(collection: string, id: string): Promise<{ deleted: number }> {
+    const response = await fetch(`/api/${collection}/${id}`, {
+      method: 'DELETE',
+      headers: {
+        'Content-Type': 'application/json',
+      },
+    })
+    const { data } = await response.json()
+    return data
+  }
 }
 
 export default new ApiClient()
